@@ -23,19 +23,19 @@
 #include <kinputdialog.h>
 #include <klineedit.h>
 
-#include <ntqtextedit.h>
-#include <ntqtoolbutton.h>
-#include <ntqpopupmenu.h>
-#include <ntqwidget.h>
-#include <ntqlistview.h>
-#include <ntqlabel.h>
-#include <ntqpixmap.h>
-#include <ntqheader.h>
-#include <ntqstringlist.h>
-#include <ntqevent.h>
-#include <ntqfile.h>
-#include <ntqtextstream.h>
-#include <ntqpushbutton.h>
+#include <tqtextedit.h>
+#include <tqtoolbutton.h>
+#include <tqpopupmenu.h>
+#include <tqwidget.h>
+#include <tqlistview.h>
+#include <tqlabel.h>
+#include <tqpixmap.h>
+#include <tqheader.h>
+#include <tqstringlist.h>
+#include <tqevent.h>
+#include <tqfile.h>
+#include <tqtextstream.h>
+#include <tqpushbutton.h>
 
 #include "fileexistsdialog.h"
 #include "customconnectdialog.h"
