@@ -25,9 +25,9 @@
  
 #include <kstandarddirs.h>
 
-#include <ntqapplication.h>
-#include <ntqevent.h>
-#include <ntqdir.h>
+#include <tqapplication.h>
+#include <tqevent.h>
+#include <tqdir.h>
 
 #include <iostream>
 #include <list>
@@ -753,7 +753,7 @@ void FtpThread::Transfer_Fxp_thread()
 	tqWarning("bla_thread: %d", alt);
 	
 	if (resume) tqWarning("WARNING: fxp resume isn't supported. overwriting file instead");
-	result == ftplib::Fxp(mp_ftp, dstftp->Ftp(), src, dst, ftplib::image, method);
+	result == ftplib::Fxp(mp_ftp, dstftp->Ftp(), src.utf8(), dst.utf8(), ftplib::image, method);
 	
 	FxpReportResult(result);
 	dstftp->FxpReportResult(result);
