@@ -15,7 +15,7 @@
 #define _LARGEFILE_SOURCE
 #define _LARGEFILE64_SOURCE 
 
-#include <ntqdatetime.h>
+#include <tqdatetime.h>
 #include "kbfileinfo.h"
 
 #include "kbitem.h"
